#[non_exhaustive]pub struct Config {
pub quantization_level: u8,
pub chroma_subsampling: bool,
pub raw: bool,
}Expand description
Video encoder configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quantization_level: u8Quantization level.
Typical value is 3-4, maximum is 14. Low values might increase the input size instead of decreasing.
chroma_subsampling: boolEnable 4:2:0 chroma subsampling.
raw: boolEnable raw mode.
In this mode no encoding is done, input frames are simply copied into the output instead.
This mode is useful running the code under a RISCV interpreter.
Other configuration options have no effect when raw mode is enabled.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn default_lossless() -> Self
pub fn default_lossless() -> Self
Returns default lossless configuration.
Sourcepub fn default_raw() -> Self
pub fn default_raw() -> Self
Returns default raw mode configuration.