Encoder

Struct Encoder 

pub struct Encoder { /* private fields */ }
Video encoder.

This encoder uses semi-standard pipeline with the simplest and fastest implementation for each stage. Currently the following stages are implemented.

StageHow it is implemented
RGB to YUV conversionPGF (no division).
TransformHaar transform (no division).
QuantizationScalar quantization without a deadzone.
Motion estimationSimple delta encoding.
Bit encoderSign-magniude conversion and rANS encoder.

Example

use core::num::NonZero;
use corevm_codec::video;

let rgb_frame = [
    0,   0, 0,
    100, 0, 0,
    0, 100, 0,
    0, 0, 100,
];
let width = NonZero::new(2).unwrap();
let height = width;
let mut output = Vec::new();
let config = video::Config::default();
let mut encoder = video::Encoder::new(width, height, config);
encoder.start(&mut output);
encoder.write_rgb888_frame(&rgb_frame, &mut output);
encoder.finish(&mut output);

Implementations

Source

impl Encoder

pub fn new(width: NonZero<u16>, height: NonZero<u16>, config: Config) -> Self

Creates new encoder with the provided width, height, and configuration.

pub fn write_rgb888_frame( &mut self, rgb_frame: &[u8], output: &mut impl Output, ) -> Stats

Encode RGB888 frame and append the resulting bytes to the output.

pub fn write_rgb888_indexed8_frame( &mut self, indexed_rgb_frame: &[u8], output: &mut impl Output, ) -> Stats

Encode indexed RGB888 frame and append the resulting bytes to the output.

The frame consists of a 256-color palette and an array of 8-bit indices into the palette. Each palette element is encoded as RGB888.

pub fn start(&mut self, output: &mut impl Output)

Write stream header.

pub fn finish(self, _output: &mut impl Output)

Write stream footer.

This is currently empty but might change in the future.